# Coloury
> ## Make your ASCII art beautiful!

```
import coloury

# Example

text = """
  cccc yy   yy   aa aa nn nnn  rr rr    aa aa zzzzz   eee  
cc     yy   yy  aa aaa nnn  nn rrr  r  aa aaa   zz  ee   e 
cc      yyyyyy aa  aaa nn   nn rr     aa  aaa  zz   eeeee  
 ccccc      yy  aaa aa nn   nn rr      aaa aa zzzzz  eeeee 
        yyyyy                                              
"""

output = coloury.purplish(text)

print(output)
```

All cosmetic styles:
## purplish
## grellow
## green_flames
## crimson
## flaming
## pink

> ## Check CIA out on **[GitHub](https://github.com/CodeIntelligenceAgency)**!